'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _path = require('path');

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _exists = require('./utils/exists');

var _exists2 = _interopRequireDefault(_exists);

var _extract = require('./utils/previews/extract');

var _extract2 = _interopRequireDefault(_extract);

var _resize = require('./utils/previews/resize');

var _resize2 = _interopRequireDefault(_resize);

var _write = require('./utils/previews/write');

var _write2 = _interopRequireDefault(_write);

var _progress = require('./utils/progress');

var _progress2 = _interopRequireDefault(_progress);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Checks path object is string
 * @param  {String} path            Path object, hopefully, a string
 * @param  {String} functionCalling name of function calling
 * @return {Void}
 */
function checkPath(path) {
  if (typeof path !== 'string') {
    var err = new TypeError('Provided path must be a string.');
    throw err;
  }
}

/** Class representing a RAW-format photo and it's information */

var Rawly = function () {
  /**
   * Create an instance of Rawly
   * @param {String} path - Absolute path to file
   */
  function Rawly(path) {
    _classCallCheck(this, Rawly);

    checkPath(path);
    var fileExists = (0, _exists2.default)(path);
    if (fileExists instanceof Error) throw fileExists;

    this.path = path;
    this.info = (0, _path.parse)(path);
    this.previewExtracted = this.previewAlreadyExtracted();
  }

  /**
   * Check if a preview is aready created
   * @param {String}   path - Absolute path to file
   * @return {Boolean}        If a preview already exists of not
   */


  _createClass(Rawly, [{
    key: 'previewAlreadyExtracted',
    value: function previewAlreadyExtracted() {
      var _info = this.info;
      var dir = _info.dir;
      var name = _info.name;
      var ext = _info.ext;

      var globExp = dir + '/' + name + '!(' + ext + '|.xmp)';
      var result = _glob2.default.sync(globExp);

      if (result.length > 0) return true;

      return false;
    }

    /**
     * Extract previews from RAW-file
     * @param  {size}    size - Size of extracted preview
     * @param  {String}  suffix=''       - Suffix to append to filename of preview
     * @return {Promise}                   Resolves Promise if files are extracted or not
     */

  }, {
    key: 'extractPreview',
    value: function extractPreview(size) {
      var _this = this;

      var suffix = arguments.length <= 1 || arguments[1] === undefined ? '' : arguments[1];

      return new _bluebird2.default(function (resolve) {
        if (_this.previewExtracted) {
          _progress2.default.tick();
          return resolve(false);
        }

        return (0, _extract2.default)(_this.path).then((0, _resize2.default)(size)).then((0, _write2.default)(_this.info, suffix)).then(function (done) {
          _progress2.default.tick();
          _this.previewExtracted = done;
          return resolve(done);
        });
      });
    }
  }]);

  return Rawly;
}();

exports.default = Rawly;